#!/bin/sh
# /etc/init.d/ps10.sh
#
PATH=/bin:/usr/bin:/sbin:/usr/sbin
PIDDIR=/var/run
LOGDIR=/var/log/Mahr
PS10HOME=/opt/Mahr/ps10
PS10DATA=/var/opt/Mahr/ps10

start() {
    echo "Starting ps10"

    if [ -e $PIDDIR/ps10tool.pid -a -e $PIDDIR/ps10_app.pid ]; then
	    logger "init.d/ps10.sh: already running"
	    exit 0
    fi

    test -d ${PS10DATA}/results || mkdir ${PS10DATA}/results

    cd ${PS10HOME}

    ./create_backing_storage.sh
    ./mass_storage.sh on

    # create core files
    if [ -d ${PS10DATA}/results/coredump ]; then
        sysctl -w kernel.core_pattern="${PS10DATA}/results/coredump/core_%e.%p"
    else
        sysctl -w kernel.core_pattern='/tmp/core_%e.%p'
    fi
    ulimit -c unlimited

    export SEGFAULT_SIGNALS="all"
    start-stop-daemon --start --background \
    --make-pidfile --pidfile $PIDDIR/ps10tool.pid \
	--exec ${PS10HOME}/ps10tool -- -r -T5

    if [ $? -eq 0 ]; then
	echo -n "ps10tool "
    else
	echo "failed!"
    fi

    . /etc/profile.d/qt

    (
        start-stop-daemon --start --make-pidfile \
	        --pidfile $PIDDIR/ps10_app.pid \
	        --exec ${PS10HOME}/ps10_app

        if [ ! -e /etc/no_poweroff -a ! -e /tmp/ps10_stop ]; then 
            echo "Shutting down due to sudden ps10_app exit"
            halt -p
        fi
        rm -f /tmp/ps10_stop
    ) &

    if [ $? -eq 0 ]; then
	echo "ps10_app."
    else
	echo "failed!"
    fi
}

stop() {
    echo "Stopping ps10"
    touch /tmp/ps10_stop

    start-stop-daemon --stop --retry INT/20/KILL/5 \
	--pidfile $PIDDIR/ps10_app.pid ps10_app
    if [ ! $? -eq 0 ]; then
	    echo "failed!"
    fi

    start-stop-daemon --stop --retry INT/20/KILL/5 \
	--pidfile $PIDDIR/ps10tool.pid ps10tool
    if [ ! $? -eq 0 ]; then
	    echo "failed!"
    fi

    rm -f $PIDDIR/ps10_app.pid $PIDDIR/ps10tool.pid

    # TODO: remove this
    if [ -x /usr/local/bin/logrotate.sh ]; then
	killall logrotate.sh
    fi
}


case "$1" in
    start)
	start
	;;

    stop)
	stop
	;;

    restart|force-reload)
	stop
	start
	;;
    *)
	echo "Usage: $0 {start|stop|restart|force-reload}"
	exit 1
	;;
esac

exit 0
